
import pytest

@pytest.fixture
def mapping_response():
    return {'responseHeader': {'QTime': 0, 'params': {'mm': '100%', 'q': '*:*', 'defType': 'edismax', 'facet_min_count': '1', 'hl': 'false', 'start': '0', 'q.op': 'AND', 'fq': 'subject_id:"MONDO\\:0020121" OR object_id:"MONDO\\:0020121"', 'facet.mincount': '1', 'rows': '20', 'facet': 'true'}}, 'response': {'num_found': 9, 'start': 0, 'docs': [{'subject_id': 'MONDO:0020121', 'predicate_id': 'skos:exactMatch', 'object_id': 'DOID:9884', 'mapping_justification': 'semapv:UnspecifiedMatching', 'subject_label': 'muscular dystrophy', 'object_label': 'muscular dystrophy', 'mapping_source': ['mondo'], 'id': 'bddb6b51-f6ee-477f-8573-ba24a37d1a38', 'highlighting': None}, {'subject_id': 'MONDO:0020121', 'predicate_id': 'skos:exactMatch', 'object_id': 'ICD10CM:G71.0', 'mapping_justification': 'semapv:UnspecifiedMatching', 'subject_label': 'muscular dystrophy', 'object_label': 'Muscular dystrophy', 'mapping_source': ['mondo'], 'id': 'd90ea6b2-e19c-4501-8d55-4f3eae422050', 'highlighting': None}, {'subject_id': 'MONDO:0020121', 'predicate_id': 'skos:exactMatch', 'object_id': 'MEDGEN:44527', 'mapping_justification': 'semapv:UnspecifiedMatching', 'subject_label': 'muscular dystrophy', 'mapping_source': ['mondo'], 'id': '56d49794-5803-4b3b-88c9-df488c195c2b', 'highlighting': None}, {'subject_id': 'MONDO:0020121', 'predicate_id': 'skos:exactMatch', 'object_id': 'NCIT:C84910', 'mapping_justification': 'semapv:UnspecifiedMatching', 'subject_label': 'muscular dystrophy', 'object_label': 'Muscular Dystrophy', 'mapping_source': ['mondo'], 'id': 'a199bc71-96e7-47c5-975a-16f22640fbf6', 'highlighting': None}, {'subject_id': 'MONDO:0020121', 'predicate_id': 'skos:exactMatch', 'object_id': 'Orphanet:98473', 'mapping_justification': 'semapv:UnspecifiedMatching', 'subject_label': 'muscular dystrophy', 'object_label': 'Muscular dystrophy', 'mapping_source': ['mondo'], 'id': '69ac3383-01cc-4b99-8efa-77ca8f5e517e', 'highlighting': None}, {'subject_id': 'MONDO:0020121', 'predicate_id': 'skos:exactMatch', 'object_id': 'SCTID:73297009', 'mapping_justification': 'semapv:UnspecifiedMatching', 'subject_label': 'muscular dystrophy', 'mapping_source': ['mondo'], 'id': '6e55cc83-adcb-459c-8224-d85a382b28b6', 'highlighting': None}, {'subject_id': 'MONDO:0020121', 'predicate_id': 'skos:exactMatch', 'object_id': 'UMLS:C0026850', 'mapping_justification': 'semapv:UnspecifiedMatching', 'subject_label': 'muscular dystrophy', 'mapping_source': ['mondo'], 'id': 'c2af8be2-4c06-4a56-9775-d5710285b51e', 'highlighting': None}, {'subject_id': 'MONDO:0020121', 'predicate_id': 'skos:exactMatch', 'object_id': 'icd11.foundation:1464662404', 'mapping_justification': 'semapv:UnspecifiedMatching', 'subject_label': 'muscular dystrophy', 'mapping_source': ['mondo'], 'id': '89e37c11-8384-48a4-9794-807e18c3c531', 'highlighting': None}, {'subject_id': 'MONDO:0020121', 'predicate_id': 'skos:exactMatch', 'object_id': 'MESH:D009136', 'mapping_justification': 'semapv:UnspecifiedMatching', 'subject_label': 'muscular dystrophy', 'mapping_source': ['mondo'], 'id': '33b82dd9-0180-40ed-998a-396cd1fd997b', 'highlighting': None}]}, 'facet_counts': {'facet_fields': {}, 'facet_queries': {}}, 'highlighting': {}}




import pytest

@pytest.fixture
def mappings():
    return {'limit': 20, 'offset': 0, 'total': 9, 'items': [{'subject_id': 'MONDO:0020121', 'subject_label': 'muscular dystrophy', 'predicate_id': 'skos:exactMatch', 'object_id': 'DOID:9884', 'object_label': 'muscular dystrophy', 'mapping_justification': 'semapv:UnspecifiedMatching', 'id': 'bddb6b51-f6ee-477f-8573-ba24a37d1a38', 'mapping_source': ['mondo'], 'highlighting': None}, {'subject_id': 'MONDO:0020121', 'subject_label': 'muscular dystrophy', 'predicate_id': 'skos:exactMatch', 'object_id': 'ICD10CM:G71.0', 'object_label': 'Muscular dystrophy', 'mapping_justification': 'semapv:UnspecifiedMatching', 'id': 'd90ea6b2-e19c-4501-8d55-4f3eae422050', 'mapping_source': ['mondo'], 'highlighting': None}, {'subject_id': 'MONDO:0020121', 'subject_label': 'muscular dystrophy', 'predicate_id': 'skos:exactMatch', 'object_id': 'MEDGEN:44527', 'object_label': None, 'mapping_justification': 'semapv:UnspecifiedMatching', 'id': '56d49794-5803-4b3b-88c9-df488c195c2b', 'mapping_source': ['mondo'], 'highlighting': None}, {'subject_id': 'MONDO:0020121', 'subject_label': 'muscular dystrophy', 'predicate_id': 'skos:exactMatch', 'object_id': 'NCIT:C84910', 'object_label': 'Muscular Dystrophy', 'mapping_justification': 'semapv:UnspecifiedMatching', 'id': 'a199bc71-96e7-47c5-975a-16f22640fbf6', 'mapping_source': ['mondo'], 'highlighting': None}, {'subject_id': 'MONDO:0020121', 'subject_label': 'muscular dystrophy', 'predicate_id': 'skos:exactMatch', 'object_id': 'Orphanet:98473', 'object_label': 'Muscular dystrophy', 'mapping_justification': 'semapv:UnspecifiedMatching', 'id': '69ac3383-01cc-4b99-8efa-77ca8f5e517e', 'mapping_source': ['mondo'], 'highlighting': None}, {'subject_id': 'MONDO:0020121', 'subject_label': 'muscular dystrophy', 'predicate_id': 'skos:exactMatch', 'object_id': 'SCTID:73297009', 'object_label': None, 'mapping_justification': 'semapv:UnspecifiedMatching', 'id': '6e55cc83-adcb-459c-8224-d85a382b28b6', 'mapping_source': ['mondo'], 'highlighting': None}, {'subject_id': 'MONDO:0020121', 'subject_label': 'muscular dystrophy', 'predicate_id': 'skos:exactMatch', 'object_id': 'UMLS:C0026850', 'object_label': None, 'mapping_justification': 'semapv:UnspecifiedMatching', 'id': 'c2af8be2-4c06-4a56-9775-d5710285b51e', 'mapping_source': ['mondo'], 'highlighting': None}, {'subject_id': 'MONDO:0020121', 'subject_label': 'muscular dystrophy', 'predicate_id': 'skos:exactMatch', 'object_id': 'icd11.foundation:1464662404', 'object_label': None, 'mapping_justification': 'semapv:UnspecifiedMatching', 'id': '89e37c11-8384-48a4-9794-807e18c3c531', 'mapping_source': ['mondo'], 'highlighting': None}, {'subject_id': 'MONDO:0020121', 'subject_label': 'muscular dystrophy', 'predicate_id': 'skos:exactMatch', 'object_id': 'MESH:D009136', 'object_label': None, 'mapping_justification': 'semapv:UnspecifiedMatching', 'id': '33b82dd9-0180-40ed-998a-396cd1fd997b', 'mapping_source': ['mondo'], 'highlighting': None}]}
